curator
=======

CLI library designer for the **Librarian** API.

**Curator** allows for simple card design and storage in a **Librarian** library
database. To enable highly general use **Curator** will do nothing more then allow
creation and storage of simple card information and does nothing to interpreted
this data or design how cards may interact with each other.

This installs a ``curator`` command line tool for manipulating **Librarian**
card databases.

Links
=====

Curator Github: https://github.com/Nekroze/curator
Librarian PyPi: https://pypi.python.org/pypi/librarian
